{{- define "polaris.vault.client.environment" }}
{{ if (eq .Values.vault.instance "old") }}
- name: "SWIP_VAULT_ADDRESS"
  value: {{ required "vault.address must be specified" .Values.vault.address | quote }}
- name: "VAULT_CACERT"
  value: "/var/run/secrets/vault/client/ca.crt"
{{ else }}
- name: "SWIP_VAULT_ADDRESS"
  value:  https://vault:8200
- name: "VAULT_CACERT"
  value: "/var/run/secrets/vault/ca/ca.crt"
{{ end }}
- name: "VAULT_CLIENT_KEY"
  value: "/var/run/secrets/vault/client/tls.key"
- name: "VAULT_CLIENT_CERT"
  value: "/var/run/secrets/vault/client/tls.crt"
{{- end }}

{{- define "polaris.vault.server.environment" }}
{{ if (eq .Values.vault.instance "old") }}
- name: "SWIP_VAULT_ADDRESS"
  value:  {{ .Values.vault.address | quote }}
- name: "VAULT_CACERT"
  value: "/var/run/secrets/vault/server/ca.crt"
{{ else }}
- name: "SWIP_VAULT_ADDRESS"
  value:  https://vault:8200
- name: "VAULT_CACERT"
  value: "/var/run/secrets/vault/ca/ca.crt"
{{ end }}
- name: "VAULT_CLIENT_KEY"
  value: "/var/run/secrets/vault/server/tls.key"
- name: "VAULT_CLIENT_CERT"
  value: "/var/run/secrets/vault/server/tls.crt"
{{- end }}

{{- define "polaris.vault.client.volumemount" }}
- mountPath: "/var/run/secrets/vault/client"
  name: "vault-client"
  readOnly: true
{{ if (eq .Values.vault.instance "new") }}
- mountPath: "/var/run/secrets/vault/ca"
  name: "vault-server-ca"
  readOnly: true
{{ end }}
{{- end }}

{{- define "polaris.vault.server.volumemount" }}
- mountPath: "/var/run/secrets/vault/server"
  name: "vault-server"
  readOnly: true
{{ if (eq .Values.vault.instance "new") }}
- mountPath: "/var/run/secrets/vault/ca"
  name: "vault-server-ca"
  readOnly: true
{{ end }}
{{- end }}

{{- define "polaris.vault.client.volume" }}
{{ if (eq .Values.vault.instance "new") }}
- name: "vault-client"
  secret:
    secretName: "vault-read-only"
- name: vault-server-ca
  secret:
    defaultMode: 420
    secretName: vault-tls-certificate-new
{{else}}
- name: "vault-client"
  secret:
    secretName: "auth-client-tls-certificate"
{{ end }}
{{- end }}

{{- define "polaris.vault.server.volume" }}
{{ if (eq .Values.vault.instance "new") }}
- name: "vault-server"
  secret:
    secretName: "vault-read-write-auth"
- name: vault-server-ca
  secret:
    defaultMode: 420
    secretName: vault-tls-certificate-new
{{ else }}
- name: "vault-server"
  secret:
    secretName: "auth-server-tls-certificate"
{{ end }}
{{- end }}

{{- define "polaris.tds.vault.client.volume" }}
{{ if (eq .Values.vault.instance "new") }}
- name: "vault-client"
  secret:
    secretName: "vault-read-write-tds"
- name: vault-server-ca
  secret:
    defaultMode: 420
    secretName: vault-tls-certificate-new
{{ else }}
- name: "vault-client"
  secret:
    secretName: "tds-code-analysis-tls-certificate"
{{ end }}
{{- end }}


{{- define "polaris.vault.migrator.client.volume" }}
{{ if (eq .Values.vault.instance "new") }}
- name: "vault-client"
  secret:
    secretName: "vault-migrator"
- name: vault-server-ca
  secret:
    defaultMode: 420
    secretName: vault-tls-certificate-new
{{ else }}
- name: "vault-client"
  secret:
    secretName: "vault-migrator-tls-certificate"
{{ end }}
{{- end }}
