#!/bin/bash

# Enforce shell discipline
set -euo pipefail

export RELEASE_NAME="${ENVIRONMENT_NAME}-polaris-auth-service"

helm3_release=$(helm3 ls --output=json -n ${ENVIRONMENT_NAME} | jq ".[] | select(.name==\"${RELEASE_NAME}\")")

helm2_release=$(helm ls --output=json --namespace ${ENVIRONMENT_NAME} | jq ".Releases[] | select(.Name==\"${RELEASE_NAME}\")")

# Try and find this release in helm3, if not upgrade it to helm3 (can be removed post 2020.03)
if [ "${helm3_release}" = "" ]; then
    if [ "${helm2_release}" != "" ]; then
        printf "\nRunning helm 3 migration for ${RELEASE_NAME}.\n"
        helm3 2to3 convert ${RELEASE_NAME}

        # pre-helm 3 migrations (drop hpas as we've moving api versions) this can be removed post 2020.03
        kubectl delete hpa auth-server -n ${ENVIRONMENT_NAME} 
    fi
else
    printf "\nRelease ${RELEASE_NAME} already converted to helm 3.\n"
fi

helm3 upgrade ${RELEASE_NAME} ${chart_file_name} --install \
    --set vault.address=https://${ENVIRONMENT_NAME}-polaris-db-vault:8200 \
    --set globalMinReplicas=${min_replica_count} \
    --set globalMaxReplicas=${max_replica_count} \
    --set environment=${ENVIRONMENT_NAME} \
    --set rootDomain=${POLARIS_ROOT_DOMAIN} \
    --namespace ${ENVIRONMENT_NAME} \
    -f template_overrides_${chart_name}_${template_name}.yaml \
    -f external_overrides_${chart_name}.yaml
