{{/* init container image.  */}}
{{- define "synopsys.image.init.container" }}
- name: polaris-init
  image: {{ .Values.synopsysInit.image }}:{{ .Values.synopsysInit.imageTag }}
  imagePullPolicy: {{ .Values.synopsysInit.imagePullPolicy }}
{{- end }}

{{/* postgres arguments that will be used by init container to verify.  */}}
{{- define "init.container.postgres.args" }}
- "--postgres-host=$(POSTGRES_HOST)" # database host
- "--postgres-password=$(POSTGRESQL_PASSWORD)" # database password
- "--postgres-port=$(POSTGRES_PORT)" # database port
- "--postgres-user=$(POSTGRESQL_USER)" # database user
- "--postgres-ssl-mode=$(POSTGRES_SSL_MODE)" # SSL mode
{{- end }}

{{/* init container wait for postgres vault database to be pinged.  */}}
{{- define "init.container.wait.for.postgres" }}
{{- include "synopsys.image.init.container" . }}
  env:
  {{- include "polaris.postgres.init.environment" . | indent 2 }}
  args:
  - "--postgres-database=vault" # database name
  {{- include "init.container.postgres.args" . | indent 2 }}
{{- end }}

{{/* init container wait for vault to be up.  */}}
{{- define "init.container.wait.for.vault.postgres" }}
{{- include "synopsys.image.init.container" . }}
  args:
  - --http-readiness-check-urls=https://vault:8200/v1/sys/health?standbycode=204&uninitcode=204&
{{- end }}

{{/* init container wait for event store to be up.  */}}
{{- define "init.container.wait.for.eventstore" }}
{{- include "synopsys.image.init.container" . }}
  args:
  - --http-readiness-check-urls=http://eventstore:2112/stats
{{- end }}

{{/* init container wait for auth service to be up.  */}}
{{- define "init.container.wait.for.auth" }}
{{- include "synopsys.image.init.container" . }}
  args:
  - "--http-readiness-check-urls=http://auth-server:80/readiness" # readiness URL
{{- end }}

{{/* init container wait for vault and eventstore service to be up.  */}}
{{- define "init.container.wait.for.vault.eventstore" }}
{{- include "synopsys.image.init.container" . }}
  args:
  - "--http-readiness-check-urls=http://eventstore:2112/stats,https://vault:8200/v1/sys/health?standbycode=204&uninitcode=204&" # readiness URL
{{- end }}