{{- define "reporting.postgres.credentials" }}
- name: "POSTGRES_HOST"
  value: {{ .Values.postgres.hostname | quote }}
- name: "POSTGRES_PORT"
  value: {{ .Values.postgres.port | quote }}
- name: "POSTGRES_PASSWORD"
  valueFrom:
    secretKeyRef:
      name: "cloudsql"
      key: "reporting_db_password"
- name: "POSTGRES_USERNAME"
  valueFrom:
    secretKeyRef:
      name: "cloudsql"
      key: "reporting_db_username"
{{- end }}

{{- define "reporting.postgres.container"}}
- name: "postgres"
  image: {{ include "polaris.image.name" (merge (dict "serviceName" "postgres") .) }}
  command: ["/cloud_sql_proxy", "-instances=$(CLOUDSQL_INSTANCE_NAME)=tcp:0.0.0.0:5432","-credential_file=/secrets/cloudsql/credentials.json"]
  ports:
  - containerPort: 5432
  volumeMounts:
  - name: "cloudsql-instance-credentials"
    mountPath: "/secrets/cloudsql"
    readOnly: true
  env:
  - name: "CLOUDSQL_INSTANCE_NAME"
    valueFrom:
      secretKeyRef:
        name: "cloudsql-instance-credentials"
        key: "instance-name"
{{- end }}

{{- define "reporting.onprem_postgres.credentials" }}
- name: "POSTGRES_HOST"
  valueFrom:
    configMapKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_HOST"
- name: "POSTGRES_PORT"
  valueFrom:
    configMapKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_PORT"
- name: "POSTGRES_PASSWORD"
  valueFrom:
    secretKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_PASSWORD"
- name: "POSTGRES_USERNAME"
  valueFrom:
    secretKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_USER"
{{- end }}

{{- define "reporting.vault.client.environment" }}
- name: "SWIP_VAULT_ADDRESS"
  value: {{ .Values.vault.address | quote }}
- name: "VAULT_CACERT"
  value: "/mnt/vault/ca/vault_cacrt"
- name: "VAULT_CLIENT_KEY"
  value: "/mnt/vault/key/vault_client_key"
- name: "VAULT_CLIENT_CERT"
  value: "/mnt/vault/cert/vault_client_cert"
{{- end }}

{{- define "reporting.vault.server.environment" }}
- name: "SWIP_VAULT_ADDRESS"
  value: {{ .Values.vault.address | quote }}
- name: "VAULT_CACERT"
  value: "/mnt/vault/ca/vault_cacrt"
- name: "VAULT_CLIENT_KEY"
  value: "/mnt/vault/key/vault_server_key"
- name: "VAULT_CLIENT_CERT"
  value: "/mnt/vault/cert/vault_server_cert"
{{- end }}

{{- define "reporting.common.environment" }}
- name: "CONNECTION_POOL_SIZE"
  value: "10"
- name: "LOG_LEVEL"
  value: "INFO"
- name: "SPRING_PROFILE"
  value: {{ .Values.spring.profile | quote }}
- name: "SWIP_ENVIRONMENT_NAME"
  value: {{ required "environment must be defined" .Values.environment | quote }}
- name: "SWIP_ROOT_DOMAIN"
  value: {{ required "rootDomain must be defined" .Values.rootDomain | quote }}
- name: "REPORTING_STANDALONE"
  value: {{ .Values.isReportingStandalone | quote }}
{{- end }}

{{- define "reporting.postgres.ssl.environment" }}
- name: "POSTGRES_SSL_MODE"
  value: {{ .Values.postgres.sslMode | quote }}
- name: "POSTGRES_SSL_CERTIFICATE_SOURCE"
  value: {{ .Values.postgres.sslCertificateSource | quote }}
- name: "POSTGRES_SSL_TRUST_STORE_PATH"
  value: {{ .Values.postgres.sslTrustStorePath | quote }}
{{- end }}

{{- define "reporting.autoscaling.common" }}
---
apiVersion: "autoscaling/v2beta1"
kind: "HorizontalPodAutoscaler"
metadata:
  name: {{ .serviceName | quote }}
spec:
  maxReplicas: {{ .Values.globalMaxReplicas }}
  minReplicas: {{ .Values.globalMinReplicas }}
  scaleTargetRef:
    apiVersion: "extensions/v1beta1"
    kind: "Deployment"
    name: {{ .serviceName | quote }}
  metrics:
  - type: "Resource"
    resource:
      name: "cpu"
      targetAverageUtilization: 85
{{- end }}

{{- define "reporting.onprem.init.container" }}
  - name: polaris-init
    image: gcr.io/snps-polaris-onprem-dev/polaris-init:1.0.0
    env:                                 
    - name: POD_NAMESPACE
      valueFrom:
        fieldRef:
          fieldPath: metadata.namespace
    - name: POSTGRES_HOST
      valueFrom:
        configMapKeyRef:
          key: POSTGRESQL_HOST
          name: postgresql-config
    - name: POSTGRES_PORT
      valueFrom:
        configMapKeyRef:
          key: POSTGRESQL_PORT
          name: postgresql-config
    - name: POSTGRESQL_USER
      valueFrom:
        secretKeyRef:
          key: POSTGRESQL_USER
          name: postgresql-config
    - name: POSTGRESQL_PASSWORD
      valueFrom:
        secretKeyRef:
          key: POSTGRESQL_PASSWORD
          name: postgresql-config
    - name: POSTGRES_SSL_MODE
      valueFrom:
        configMapKeyRef:
          key: POSTGRES_SSL_MODE
          name: postgresql-config
    args:
    - "--http-readiness-check-urls=http://auth-server.$(POD_NAMESPACE).svc.cluster.local:80/readiness" # readiness URL
    - "--postgres-database=postgres" # Postgres database name
    - "--postgres-host=$(POSTGRES_HOST)" # Postgres database host
    - "--postgres-password=$(POSTGRESQL_PASSWORD)" # Postgres database password
    - "--postgres-port=$(POSTGRES_PORT)" # Postgres database port
    - "--postgres-user=$(POSTGRESQL_USER)" # Postgres database user
{{- end }}