{{- define "minio.pv.migrator"}}
- name: rp-storage-migrator
  image: gcr.io/snps-polaris-onprem-dev/rp-reports-pv-migrate:0.0.3
  imagePullPolicy: Always
  resources: {}
  terminationMessagePath: /dev/termination-log
  terminationMessagePolicy: File
  command: [ "migrate.sh" ]
  volumeMounts:
  - name: "storage"
    mountPath: "/storage"
  - name: gcs-credentials
    mountPath: "/etc/gcs-credentials"
    readOnly: true
  env:
  {{- include "minio.credentials" . | indent 2}}
{{- end }}

{{- define "environment.details" }}
{{- if eq .Values.minio.migrate.enabled true }}
- name: "MINIO_BUCKET"
  value: {{ .Values.environment }}-rp-report-storage
{{- else }}
- name: "MINIO_BUCKET"
  value: reports
{{- end }}
{{- end }}

{{- define "minio.hosts" }}
- name: "MINIO_HOST"
  value: {{ .Values.minio.hostname | quote }}
- name: "MINIO_PORT"
  value: {{ .Values.minio.port | quote }}
{{- end }}

{{- define "minio.credentials" }}
- name: "MINIO_ACCESS_KEY"
  valueFrom:
    secretKeyRef:
      name: "swip-tools-minio"
      key: "access_key"
- name: "MINIO_SECRET_KEY"
  valueFrom:
    secretKeyRef:
      name: "swip-tools-minio"
      key: "secret_key"
- name: "MINIO_REGION"
  value: {{ .Values.minio.region | quote }}
- name: NAMESPACE
  valueFrom:
    fieldRef:
      apiVersion: v1
      fieldPath: metadata.namespace
{{- if eq .Values.deploymentType "cloud" }}
- name: GOOGLE_APPLICATION_CREDENTIALS
  value: "/etc/gcs-credentials/credentials.json"
- name: GOOGLE_PROJECT
  value: {{ .Values.gcp.project | quote }}
{{- end }}
- name: MINIO_BROWSER
  value: "off"
{{- end }}
