{{- define "polaris.postgres.container" }}
{{ if (eq .Values.deploymentType "cloud" ) }}
- name: "postgresql"
  image: "gcr.io/cloudsql-docker/gce-proxy:1.11"
  command: ["/cloud_sql_proxy"]
  args: 
  - "-instances=$(CLOUDSQL_INSTANCE_NAME)=tcp:5432"
  - "-credential_file=/secrets/cloudsql/credentials.json"
  - "-verbose={{ .Values.cloudSqlProxyDebugLogs }}"
  volumeMounts:
  - name: "cloudsql-instance-credentials"
    mountPath: "/secrets/cloudsql"
    readOnly: true
  env:
  - name: "POSTGRES_DB"           # Deprecated
    value: {{ .db_name | quote }} # Deprecated
  - name: "PGDATABASE"
    value: {{ .db_name | quote }}
  - name: "CLOUDSQL_INSTANCE_NAME"
    valueFrom:
      secretKeyRef:
        name: "cloudsql-instance-credentials"
        key: "instance-name"
  ports:
  - name: "postgresql"
    protocol: "TCP"
    containerPort: 5432
  resources:
    requests:
      cpu: "250m"
      memory: "256Mi"
    limits:
      cpu: "500m"
      memory: "1Gi"
  terminationMessagePath: "/dev/termination-log"
  terminationMessagePolicy: "File"
{{ end }}
{{- end }}

{{- define "polaris.postgres.volume" }}
{{ if (eq .Values.deploymentType "cloud" ) }}
- name: "cloudsql-instance-credentials"
  secret:
    secretName: "cloudsql-instance-credentials"
{{ end }}
{{- end }}

{{- define "polaris.postgres.environment" }}
{{ if (eq .Values.deploymentType "cloud" ) }}
- name: "POSTGRES_HOST" # Deprecated
  value: "postgresql"   # Deprecated
- name: "PGHOST"
  value: "postgresql"
- name: "POSTGRES_PORT" # Deprecated
  value: "5432"         # Deprecated
- name: "PGPORT"
  value: "5432"
- name: "CLOUDSQL_PASSWORD" # Deprecated
  valueFrom:                # Deprecated
    secretKeyRef:           # Deprecated
      name: "cloudsql"      # Deprecated
      key: "password"       # Deprecated
- name: "PGPASSWORD"
  valueFrom:
    secretKeyRef:
      name: "cloudsql"
      key: "password"
- name: "CLOUDSQL_USERNAME" # Deprecated
  valueFrom:                # Deprecated
    secretKeyRef:           # Deprecated
      name: "cloudsql"      # Deprecated
      key: "username"       # Deprecated
- name: "PGUSER"
  valueFrom:
    secretKeyRef:
      name: "cloudsql"
      key: "username"
{{ else if (eq .Values.deploymentType "on-prem" ) }}
- name: "POSTGRES_HOST"         # Deprecated
  valueFrom:                    # Deprecated
    configMapKeyRef:            # Deprecated
      name: "postgresql-config" # Deprecated
      key: "POSTGRESQL_HOST"    # Deprecated
- name: "PGHOST"
  valueFrom:
    configMapKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_HOST"
- name: "POSTGRES_PORT"         # Deprecated
  valueFrom:                    # Deprecated
    configMapKeyRef:            # Deprecated
      name: "postgresql-config" # Deprecated
      key: "POSTGRESQL_PORT"    # Deprecated
- name: "PGPORT"
  valueFrom:
    configMapKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_PORT"
- name: "CLOUDSQL_PASSWORD"      # Deprecated
  valueFrom:                     # Deprecated
    secretKeyRef:             # Deprecated
      name: "postgresql-config"  # Deprecated
      key: "POSTGRESQL_PASSWORD" # Deprecated
- name: "PGPASSWORD"
  valueFrom:
    secretKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_PASSWORD"
- name: "CLOUDSQL_USERNAME"     # Deprecated
  valueFrom:                    # Deprecated
    secretKeyRef:            # Deprecated
      name: "postgresql-config" # Deprecated
      key: "POSTGRESQL_USER"    # Deprecated
- name: "PGUSER"
  valueFrom:
    secretKeyRef:
      name: "postgresql-config"
      key: "POSTGRESQL_USER"
{{ end }}
{{- end }}