#!/bin/bash

source /opt/scripts/vault-operations.sh

check_vault_service_status

set -euo pipefail
export VAULT_TOKEN=$POLARIS_VAULT_TOKEN
export K8S_TOKEN=$(cat /var/run/secrets/kubernetes.io/serviceaccount/token)
export K8S_API_SERVER=https://kubernetes.default
login_to_vault
is_vault_ro_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-read-only --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
is_vault_rwauth_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-read-write-auth --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
is_vault_rwtds_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-read-write-tds --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
is_polaris_webhooks_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/polaris-webhook-client-certs --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
if [[ $is_vault_ro_secret_exist -ne 200 || \
  $is_vault_rwauth_secret_exist -ne 200 || \
  $is_vault_rwtds_secret_exist -ne 200 || \
  $is_polaris_webhooks_secret_exist -ne 200 ]];then
  enable_secrets_engine_in_vault
  create_or_update_vault_policies
  enable_pki_engine_in_vault
  tune_pki_secret_engine
  enable_cert_based_authentication_in_vault
  generate_vault_read_only_certificate_for_polaris
  generate_vault_read_write_auth_certificate_for_polaris
  generate_vault_read_write_tds_certificate_for_polaris
  generate_certificate_for_polaris_webhooks
else
  echo "Vault credentials are already exist.. Skipping creation.."
fi