#!/bin/bash

check_and_renew(){
  secret_name=$1
  echo "Validating certificates under $secret_name secret"
  curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/$secret_name --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --silent | jq -r '.data."tls.crt"' | base64 -d > /tmp/tls.crt
  if openssl x509 -checkend $(( 86400 * $DAYS )) -noout -in /tmp/tls.crt;then
    echo
  else
    echo "Certificates under $secret_name is about to expire in 8 days or less.."
    renew_vault_client_certs
    exit 0
  fi
}

renew_vault_client_certs(){
  # Check if it is Sunday
  if [[ $(TZ=EST date +"%A") == "Sunday" ]];then
    echo "Proceeding for certificates renewal.."
    login_to_vault
    tune_pki_secret_engine
    enable_cert_based_authentication_in_vault
    echo "Renewing vault-read-only credentials.."
    generate_vault_read_only_certificate_for_polaris
    echo "Renewing vault-read-write-auth credentials.."
    generate_vault_read_write_auth_certificate_for_polaris
    echo "Renewing vault-read-write-tds credentials.."
    generate_vault_read_write_tds_certificate_for_polaris
    echo "Renewing polaris-webhook-client-certs credentials.."
    generate_certificate_for_polaris_webhooks
  else
    echo "Couldn't proceed for renewal because its not Sunday.."
  fi
}

check_for_expiry_and_renew_it(){
  check_and_renew "vault-read-only"
  check_and_renew "vault-read-write-auth"
  check_and_renew "vault-read-write-tds"
  check_and_renew "polaris-webhook-client-certs"
}

source /opt/scripts/vault-operations.sh

check_vault_service_status

set -euo pipefail

export VAULT_TOKEN=$POLARIS_VAULT_TOKEN
export K8S_TOKEN=$(cat /var/run/secrets/kubernetes.io/serviceaccount/token)
export K8S_API_SERVER=https://kubernetes.default

is_vault_ro_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-read-only --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
is_vault_rwauth_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-read-write-auth --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
is_vault_rwtds_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-read-write-tds --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
is_polaris_webhooks_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/polaris-webhook-client-certs --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
if [[ $is_vault_ro_secret_exist -ne 200 || \
  $is_vault_rwauth_secret_exist -ne 200 || \
  $is_vault_rwtds_secret_exist -ne 200 || \
  $is_polaris_webhooks_secret_exist -ne 200 ]];then
  echo "One of the vault-read-only, vault-read-write-auth, vault-read-write-tds and polaris-webhooks-client-certs doesn't exist.. Skipping expiry checking.."
else
  check_for_expiry_and_renew_it
fi