#!/bin/bash

source /opt/scripts/tls-commons.sh

check_for_expiry_and_renew_it(){
  curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/$CERTIFICATE_NAME --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --silent | jq -r '.data."tls.crt"' | base64 -d > /tmp/tls.crt
  openssl x509 -enddate -noout -in /tmp/tls.crt
  if openssl x509 -checkend $(( 86400 * $DAYS )) -noout -in /tmp/tls.crt;then
    echo "Certificate is good.."
  else
    echo "Certificate is about to expire in $DAYS days or less.."
    # Check if it is Sunday
    if [[ $(TZ=EST date +"%A") == "Sunday" ]];then
      echo "Renewing certificates.."
      generate_ca_csr "/tmp"
      generate_ca_config "/tmp"
      generate_vault_metadata "/tmp"
      generate_vault_tls_certificate "/tmp"
      update_kubernetes_secret "/tmp" "$CERTIFICATE_NAME"
    else
      echo "Couldn't proceed for renewal because its not Sunday.."
    fi
  fi
}

set -euo pipefail

export K8S_TOKEN=$(cat /var/run/secrets/kubernetes.io/serviceaccount/token)
export K8S_API_SERVER=https://kubernetes.default
export CERTIFICATE_NAME="vault-tls-certificate-new"

is_tls_secret_exist=$(curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/$CERTIFICATE_NAME --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" --write-out '%{http_code}' --silent --output /dev/null)
if [[ $is_tls_secret_exist -ne 200 ]];then
  echo "$CERTIFICATE_NAME certificate doesn't exist.. Skipping expiry checking.."
else
  check_for_expiry_and_renew_it
fi