#!/bin/bash

init_vault(){
  vault operator init -key-shares=1 -key-threshold=1 -format=json > /tmp/keys.json
  export UNSEAL_KEY=$(cat /tmp/keys.json | jq -r -j '.unseal_keys_b64[0]' | base64 )
  export ROOT_TOKEN=$(cat /tmp/keys.json | jq -r -j '.root_token' | base64 )
  export K8S_TOKEN=$(cat /var/run/secrets/kubernetes.io/serviceaccount/token)
  export K8S_API_SERVER=https://kubernetes.default
  cat <<EOF > /tmp/payload.json
    {
      "metadata":{
        "name":"vault-tokens"
      },
      "data":{
        "root_token":"$ROOT_TOKEN",
        "unseal_key":"$UNSEAL_KEY"
      }
    }
EOF

  curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets \
    --write-out '%{http_code}' --silent --output /dev/null \
    --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt \
    -X POST -H "Content-Type: application/json" \
    --data @/tmp/payload.json

  curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-tokens \
    --write-out '%{http_code}' --silent --output /dev/null \
    --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt \
    -X PUT -H "Content-Type: application/json" \
    --data @/tmp/payload.json
  
}

while true; do
  vault status -format=json > /tmp/status.json
  if [ $? -eq 1 ]; then
    echo "Vault service is unreachable.. sleeping for 2s.."
    sleep 2
  else
    VAULT_INIT_STATUS=$(cat /tmp/status.json | jq -r '.initialized')
    VAULT_SEAL_STATUS=$(cat /tmp/status.json | jq -r '.sealed')
    if [ "$VAULT_INIT_STATUS" == "false" ];then
      echo "Initializing vault.."
      init_vault
    else
      sleep 300
    fi
  fi
done