#!/bin/bash

unseal_vault(){
  export K8S_TOKEN=$(cat /var/run/secrets/kubernetes.io/serviceaccount/token)
  export K8S_API_SERVER=https://kubernetes.default
  curl -k $K8S_API_SERVER/api/v1/namespaces/$NAMESPACE/secrets/vault-tokens --header "Authorization: Bearer $K8S_TOKEN" --cacert /var/run/secrets/kubernetes.io/serviceaccount/ca.crt -X GET -H "Content-Type: application/json" > /tmp/keys.json
  vault operator unseal $(cat /tmp/keys.json | jq -r '.data.unseal_key' | base64 -d )
}

while true; do
  vault status -format=json > /tmp/status.json
  if [ $? -eq 1 ]; then
    echo "Vault service is unreachable.. sleeping for 2s.."
    sleep 2
  else
    VAULT_INIT_STATUS=$(cat /tmp/status.json | jq -r '.initialized')
    VAULT_SEAL_STATUS=$(cat /tmp/status.json | jq -r '.sealed')
    if [ "$VAULT_INIT_STATUS" == "true" ];then
      if [ "$VAULT_SEAL_STATUS" == "true" ];then
        echo "Unsealing vault.."
        unseal_vault
      else
        sleep 300
      fi
    else
      echo "Vault is not initialized.. Waiting for it to be initialized.."
      sleep 2
    fi
  fi
done