{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "reporting.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "reporting.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "reporting.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Common labels
*/}}
{{- define "reporting.labels" -}}
helm.sh/chart: {{ include "reporting.chart" . }}
{{ include "reporting.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "reporting.selectorLabels" -}}
app.kubernetes.io/name: {{ include "reporting.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end -}}

{{/*
Create the name of the service account to use
*/}}
{{- define "reporting.serviceAccountName" -}}
{{- if .Values.serviceAccount.create -}}
    {{ default (include "reporting.fullname" .) .Values.serviceAccount.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccount.name }}
{{- end -}}
{{- end -}}

{{/* init container wait for postgres - postgres database to be pinged.  */}}
{{- define "init.container.wait.for.postgres.database" }}
{{- include "synopsys.image.init.container" . }}
  env:
  {{- include "polaris.postgres.init.environment" . | indent 2 }}
  args:
  - "--postgres-database=postgres" # database name
  {{- include "init.container.postgres.args" . | indent 2 }}
{{- end }}

{{- define "polaris.reporting.labels" }}
environment: {{ (index .Values "environment") | default "None" | quote }}
service: {{ required "required for each file" .serviceName | quote }}
component: {{ index .Values "componentName" | default "None" | quote }}
chart: {{ .Chart.Name | quote }}
helm.sh/chart: {{ printf "%s" (default .Chart.Name "None") | quote }}
app.kubernetes.io/name: {{ .Chart.Name | quote }}
app.kubernetes.io/managed-by: {{ .Release.Service | quote }}
app.kubernetes.io/instance: {{ .Release.Name | quote }}
app.kubernetes.io/component: {{ required "required for each file" .serviceName | quote }}
app.kubernetes.io/part-of: "polaris"
{{- end }}
